Index: firmware/FTM/ftm_definitions.vhd
===================================================================
--- firmware/FTM/ftm_definitions.vhd	(revision 10159)
+++ firmware/FTM/ftm_definitions.vhd	(revision 10160)
@@ -87,10 +87,14 @@
 
 
   -- Clock conditioner interface
   constant MICROWIRE_CLK_FREQUENCY   : integer := 2000000;  -- 2 MHz
   constant LMK03000_Reset : std_logic_vector (31 downto 0) :=  x"80000000";
                                                        -- value to be written to R0 of the LMK03000 to perform a reset
-                                                       -- see LMK03000 datasheet                                                                
-
+                                                       -- see LMK03000 datasheet
+  constant LMK03000_REGISTER_WIDTH : integer := 32;
+  constant LMK03000_REGISTER_COUNT : integer := 9;  -- number of registers to
+                                                    -- be programmed in the
+                                                    -- LMK03000 including reset
+                                                 
                                                                              
 
@@ -87,10 +87,14 @@
 
 
-  -- Clock conditioner interface
+  -- Clock conditioner (LMK03000, National semiconductor) interface 
   constant MICROWIRE_CLK_FREQUENCY   : integer := 2000000;  -- 2 MHz
   constant LMK03000_Reset : std_logic_vector (31 downto 0) :=  x"80000000";
